@@ -1,6 +1,6 @@
-/*
+ /*
    Egon Animator
-   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,10 +28,11 @@ This module hides the details of stringpool and matrix handling.
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
+#include <sys/types.h>
 
 #include "egon.h"
-#include "types.h"
-#include "../common/cmalloc.h"
+
+#include <Mowitz/MwUtils.h>
 #include "../common/common.h"
 
 static char *types[] = {
@@ -52,7 +53,7 @@ int name2type(char *name)
 {
 	int i;
 	for (i = 0; types[i]; i++) {
-		if (!cstrcasecmp(types[i], name)) return i;
+		if (!MwStrcasecmp(types[i], name)) return i;
 	}
    	return -1;
 }
@@ -62,16 +63,16 @@ int name2type(char *name)
    Frees the memory used by the matrix.
 */
 
-void free_matrix(ani_object *matrix)
+void free_matrix(MwAniObject *matrix)
 {
 	/* It would be nice if this actually did something */
 }
 
 /* ---
 */
-ani_object *last_object(buffer *b)
+MwAniObject *last_object(sheet *b)
 {
-	ani_object *o;
+	MwAniObject *o;
 	if (!b) return NULL;
 	o = b->cast;
 	if (!o) return o;
@@ -81,9 +82,9 @@ ani_object *last_object(buffer *b)
 
 /* ---
 */
-ani_script *last_script(ani_object *o)
+MwAniScript *last_script(MwAniObject *o)
 {
-	ani_script *s;
+	MwAniScript *s;
 	if (!o) return NULL;
 	s = o->script;
 	if (!s) return s;
@@ -93,7 +94,7 @@ ani_script *last_script(ani_object *o)
 
 /* ---
 */
-int ins_format(buffer *buf, ani_object *o, ani_script *s, int format)
+int ins_format(buffer *buf, MwAniObject *o, MwAniScript *s, int format)
 {
 	if (!buf || !o || !s) return 0;
 
@@ -103,7 +104,7 @@ int ins_format(buffer *buf, ani_object *o, ani_script *s, int format)
 
 /* ---
 */
-int ret_format(buffer *buf, ani_object *o, ani_script *s)
+int ret_format(buffer *buf, MwAniObject *o, MwAniScript *s)
 {
 	if (!buf || !o || !s) return 0;
 
