@@ -25,39 +25,29 @@
  */
 
 #include <stdlib.h>
+#include <stdio.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/cursorfont.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
 
-#ifdef VMS
-#include <X11/bitmaps/tie_fighter.>
-#include <X11/bitmaps/dot.>
-#else
-#include <X11/bitmaps/tie_fighter>
-#include <X11/bitmaps/dot>
-#endif
-
 #include <X11/Xaw/Cardinals.h>
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/Viewport.h>
 #include <X11/Xaw/Box.h>
-#include "../xcommon/SiagMenuButton.h"
-#include <X11/Xaw/SimpleMenu.h>
-#include <X11/Xaw/SmeBSB.h>
-#include <X11/Xaw/SmeLine.h>
 #include <X11/Xaw/Label.h>
 #include <X11/Xaw/AsciiText.h>
 #include <X11/Xaw/Command.h>
 #include <X11/xpm.h>
 
+#include "blank.xpm"
+#include "dot.xpm"
+
+#include <Mowitz/Mowitz.h>
+
 #include "../common/common.h"
 #include "../xcommon/xcommon.h"
-#include "../xcommon/Rudegrid.h"
-#include "../xcommon/Frame.h"
-#include "../xcommon/Tooltip.h"
-#include "../xcommon/Handle.h"
 
 #include "gv.h"
 #include "../common/ps.h"
@@ -90,6 +80,8 @@ static XtResource resources[] = {
      XtOffsetOf(AppResources, page), XtRImmediate, NULL},
     {"pageMedia", "PageMedia", XtRString, sizeof(String),
      XtOffsetOf(AppResources, pagemedia), XtRImmediate, "Letter"},
+    {"antialiasing", "Antialiasing", XtRBoolean, sizeof(Boolean),
+     XtOffsetOf(AppResources, antialiasing), XtRImmediate, (XtPointer)True},
     {"forceOrientation", "Force", XtRBoolean, sizeof(Boolean),
      XtOffsetOf(AppResources, force_orientation), XtRImmediate,
      (XtPointer)False},
@@ -153,6 +145,8 @@ static XrmOptionDescRec options[] = {
     {"-nocenter", ".autoCenter", XrmoptionNoArg, "False"},
     {"-labels", ".Labels", XrmoptionNoArg, "True"},
     {"-nolabels", ".Labels", XrmoptionNoArg, "False"},
+    {"-alpha", "*Ghostview.alpha", XrmoptionNoArg, "True"},
+    {"-noalpha", "*Ghostview.alpha", XrmoptionNoArg, "False"},
     {"-quiet", "*Ghostview.quiet", XrmoptionNoArg, "True"},
     {"-noquiet", "*Ghostview.quiet", XrmoptionNoArg, "False"},
     {"-safer", "*Ghostview.safer", XrmoptionNoArg, "True"},
@@ -202,6 +196,7 @@ String fallback_resources[] = {
 #include "../xcommon/xcommon-ad.h"
 #include "../xcommon/filesel-ad.h"
 #include "../xcommon/dialogs-ad.h"
+#include "../xcommon/nws-ad.h"
 #include "gvu-ad.h"
     NULL
 };
@@ -232,8 +227,9 @@ int	current_ury;
 int	base_papersize;		/* tells where papersizes begins */
 Boolean	info_up;		/* tells if information window is up */
 int	force_setting;		/* tells if new setting override %%comments */
-Pixmap	dot_bitmap;		/* pixmap used to mark default setting */
-Pixmap	tie_fighter_bitmap;	/* bitmap used to mark forced setting */
+Icon	*blank_bitmap;
+Icon	*dot_bitmap;		/* pixmap used to mark default setting */
+Icon	*tie_fighter_bitmap;	/* bitmap used to mark forced setting */
 String	toc_text;	/* page labels (Table of Contents) */
 int	toc_length;	/* length of page label text */
 int	toc_entry_length; /* length of one entry */
@@ -293,6 +289,9 @@ int bars = 0;
         Widget             pagemediabutton;
         Widget                 pagemediamenu;
         Widget                     *pagemediaentry;
+        Widget             antialiasingbutton;
+        Widget                 antialiasingmenu;
+        Widget                     *antialiasingentry;
 	Widget		   helpbutton;
 	Widget		       helpmenu;
 	Widget			   contentsbutton;
@@ -326,7 +325,7 @@ static Widget make_command(void (*cmd)(), Widget pw, char *pm, char *tt)
                 commandWidgetClass, pw,
                 XtNforeground, color,
                 (char *)NULL);
-	pm_return = load_pixmap(pw, pm);
+	pm_return = load_pixmap(XtDisplay(pw), color, pm);
 
         XtVaSetValues(w,
                 XtNbitmap, pm_return,
@@ -334,13 +333,21 @@ static Widget make_command(void (*cmd)(), Widget pw, char *pm, char *tt)
 
         XtAddCallback(w,
                 XtNcallback, cmd, (XtPointer)NULL);
-	TooltipAdd(tooltip, w, translate(tt));
+	MwTooltipAdd(tooltip, w, _(tt));
         return w;
 }
 
 static void make_vsep(Widget pw)
 {
-	XtCreateManagedWidget("vsep", labelWidgetClass, pw, NULL, 0);
+	unsigned long bg;
+
+	XtVaGetValues(topbox,
+		XtNbackground, &bg,
+		(char *)0);
+	XtVaCreateManagedWidget("vsep",
+		labelWidgetClass, pw,
+		XtNborderColor, bg,
+		(char *)0);
 }
 
 /* There is plenty to do here */
@@ -372,9 +379,11 @@ static Widget add_menu_entry(Widget pw, char *name, char *label,
 	     void (*cb) (Widget, XtPointer, XtPointer), XtPointer * data)
 {
 	Widget w;
-	w = XtCreateManagedWidget(name, smeBSBObjectClass, pw, NULL, 0);
+	w = XtVaCreateManagedWidget(name,
+		mwLabelMEObjectClass, pw,
+		XtNlabel, _(label),
+		(char *)0);
 	XtAddCallback(w, XtNcallback, cb, data);
-	label_set(w, label);
 	return w;
 }
 
@@ -389,39 +398,22 @@ static void remake_ylayout(void)
 		(char *)0);
 }
 
-static void attach_bar(Widget w)
+static void attach_bar(Widget w, XtPointer client_data, XtPointer call_data)
 {
-	if (w == menubar) bars |= MENUBAR;
-	if (w == toolbar) bars |= TOOLBAR;
+	Widget vw = (Widget)call_data;
+	if (vw == menubar) bars |= MENUBAR;
+	if (vw == toolbar) bars |= TOOLBAR;
 	remake_ylayout();
 }
 
-static void detach_bar(Widget w)
+static void detach_bar(Widget w, XtPointer client_data, XtPointer call_data)
 {
-	if (w == menubar) bars &= ~MENUBAR;
-	if (w == toolbar) bars &= ~TOOLBAR;
+	Widget vw = (Widget)call_data;
+	if (vw == menubar) bars &= ~MENUBAR;
+	if (vw == toolbar) bars &= ~TOOLBAR;
 	remake_ylayout();
 }
 
-static Widget make_handle(Widget pw, Widget victim)
-{
-	Pixmap pm;
-	Pixel color;
-	XtVaGetValues(pw,
-		      XtNbackground, &color,
-		      (char *)0);
-	pm = load_pixmap(pw, "handlebg.xpm");
-	return XtVaCreateManagedWidget("handle",
-		handleWidgetClass, pw,
-		XtNforeground, color,
-		XtNbackgroundPixmap, pm,
-		XtNshadowWidth, 1,
-		XtNhandleDetach, detach_bar,
-		XtNhandleAttach, attach_bar,
-		XtNhandleVictim, victim,
-		(char *)0);
-}
-
 int main(int argc, char **argv)
 {
     struct stat sbuf;
@@ -432,6 +424,7 @@ int main(int argc, char **argv)
     Widget above_toc;
     Widget left_of_page;
     Widget line;
+    Widget aboutbutton;
     int i;
     Boolean set_vert_dist;
     String s1, s2;
@@ -441,7 +434,6 @@ int main(int argc, char **argv)
     static String nothing = "";
     static XawTextSelectType sarry[] =
 	    {XawselectLine, XawselectAll, XawselectNull};
-    unsigned long highlight_color, unhighlight_color;
 
     common_init("Gvu %s. No Warranty.");
 
@@ -484,28 +476,24 @@ int main(int argc, char **argv)
     toplevel = XtAppCreateShell(NULL, "Gvu", applicationShellWidgetClass,
 				dpy, NULL, ZERO);
 
+    theme_init(dpy);
+
     XtGetApplicationResources(toplevel, (XtPointer) &app_res,
 			      resources, XtNumber(resources), NULL, ZERO);
     if ((s1 = getenv(app_res.printer_variable))) app_res.default_printer = s1;
 
     /* Open Windows sometimes hands me a bad bitmap */
     if (app_res.openwindows) {
-	dot_bitmap = tie_fighter_bitmap = None;
+	blank_bitmap = dot_bitmap = tie_fighter_bitmap = None;
     } else {
-	tie_fighter_bitmap = XCreateBitmapFromData(dpy, RootWindowOfScreen(scr),
-				      tie_fighter_bits, tie_fighter_width,
-				      tie_fighter_height);
-	dot_bitmap = XCreateBitmapFromData(dpy, RootWindowOfScreen(scr),
-				      dot_bits, dot_width,
-				      dot_height);
+	blank_bitmap = X_XpmDataToIcon(XtDisplay(toplevel), blank_xpm);
+	dot_bitmap = X_XpmDataToIcon(XtDisplay(toplevel), dot_xpm);
+	tie_fighter_bitmap = X_XpmDataToIcon(XtDisplay(toplevel), dot_xpm);
     }
 
-	highlight_color = WhitePixel(XtDisplay(toplevel),
-		DefaultScreen(XtDisplay(toplevel)));
-	XtVaGetValues(toplevel, XtNbackground, &unhighlight_color, (char *)0);
-	tooltip_init(toplevel, highlight_color, unhighlight_color);
+	MwHighlightInit(toplevel);
 	tooltip = XtVaCreatePopupShell("tooltip",
-		tooltipWidgetClass, toplevel,
+		mwTooltipWidgetClass, toplevel,
 		(char *)0);
     
     /* Instantiate Popup children */
@@ -567,30 +555,40 @@ int main(int argc, char **argv)
     /* Instantiate Widgets */
 
 	topbox = XtVaCreateManagedWidget("topbox",
-		rudegridWidgetClass, toplevel,
+		mwRudegridWidgetClass, toplevel,
 		(char *)0);
 	menubar = XtVaCreateManagedWidget("menubar",
-		frameWidgetClass, topbox,
+		mwRudegridWidgetClass, topbox,
+		XtNborderWidth, 0,
+		XtNxLayout, "9 100%",
 		(char *)0);
+	MwMakeHandle(menubar, menubar, detach_bar, attach_bar);
 	menubox = XtVaCreateManagedWidget("menubox",
-		boxWidgetClass, menubar,
+		mwMenuBarWidgetClass, menubar,
+		XtNgridx, 1,
 		(char *)0);
 	bars |= MENUBAR;
-	make_handle(menubox, menubar);
 	toolbar = XtVaCreateManagedWidget("toolbar",
-		frameWidgetClass, topbox,
+		mwRudegridWidgetClass, topbox,
+		XtNborderWidth, 0,
+		XtNxLayout, "9 100%",
+		(char *)0);
+	MwMakeHandle(toolbar, toolbar, detach_bar, attach_bar);
+	toolbox = XtVaCreateManagedWidget("frame2",
+		mwFrameWidgetClass, toolbar,
+		XtNgridx, 1,
+		XtNshadowWidth, 1,
 		(char *)0);
 	toolbox = XtVaCreateManagedWidget("toolbox",
-		boxWidgetClass, toolbar,
+		boxWidgetClass, toolbox,
 		(char *)0);
 	bars |= TOOLBAR;
-	make_handle(toolbox, toolbar);
 	create_toolbar(toolbox);
 	mainarea = XtVaCreateManagedWidget("mainarea",
-		rudegridWidgetClass, topbox,
+		mwRudegridWidgetClass, topbox,
 		(char *)0);
 	status = XtVaCreateManagedWidget("status",
-		rudegridWidgetClass, topbox,
+		mwRudegridWidgetClass, topbox,
 		(char *)0);
 	label2 = XtVaCreateManagedWidget("label2",
 		labelWidgetClass, status,
@@ -608,12 +606,14 @@ int main(int argc, char **argv)
     }
 
     XtSetArg(args[0], XtNresize, False);
-    filebutton = XtCreateManagedWidget("fileButton", siagMenuButtonWidgetClass,
-				       menubox, NULL, ZERO);
-	label_set(filebutton, "File");
+    filebutton = XtVaCreateManagedWidget("fileButton",
+			mwMBButtonObjectClass, menubox,
+			XtNlabel, _("File"),
+			XtNmenu_name, "file_menu",
+			(char *)0);
 
-    filemenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				  filebutton, NULL, ZERO);
+    filemenu = XtCreatePopupShell("file_menu", mwMenuWidgetClass,
+				  menubox, NULL, ZERO);
 
 	openbutton = add_menu_entry(filemenu, "open", "Open...",
 		open_cb, NULL);
@@ -627,18 +627,20 @@ int main(int argc, char **argv)
 		save_cb, NULL);
 
 
-    line = XtCreateManagedWidget("line", smeLineObjectClass,
+    line = XtCreateManagedWidget("line", mwLineMEObjectClass,
 				 filemenu, NULL, ZERO);
 
 	quitbutton = add_menu_entry(filemenu, "quit", "Quit",
 		quit_ghostview, NULL);
 
-    pagebutton = XtCreateManagedWidget("pageButton", siagMenuButtonWidgetClass,
-				       menubox, NULL, 0/*args, 1*/);
-	label_set(pagebutton, "Page");
+    pagebutton = XtVaCreateManagedWidget("pageButton",
+			mwMBButtonObjectClass, menubox,
+			XtNlabel, _("Page"),
+			XtNmenu_name, "page_menu",
+			(char *)0);
 
-    pagemenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				  pagebutton, NULL, ZERO);
+    pagemenu = XtCreatePopupShell("page_menu", mwMenuWidgetClass,
+				  menubox, NULL, ZERO);
 
 	nextbutton = add_menu_entry(pagemenu, "next", "Next",
 		next_page, NULL);
@@ -647,13 +649,13 @@ int main(int argc, char **argv)
 	prevbutton = add_menu_entry(pagemenu, "prev", "Previous",
 		prev_page, NULL);
 
-    line = XtCreateManagedWidget("line", smeLineObjectClass,
+    line = XtCreateManagedWidget("line", mwLineMEObjectClass,
 				 pagemenu, NULL, ZERO);
 
 	centerbutton = add_menu_entry(pagemenu, "center", "Center",
 		center_page, NULL);
 
-    line = XtCreateManagedWidget("line", smeLineObjectClass,
+    line = XtCreateManagedWidget("line", mwLineMEObjectClass,
 				 pagemenu, NULL, ZERO);
 
 	markbutton = add_menu_entry(pagemenu, "mark", "Mark",
@@ -661,68 +663,82 @@ int main(int argc, char **argv)
 	unmarkbutton = add_menu_entry(pagemenu, "unmark", "Unmark",
 		unmark_page, NULL);
 
-    magstepbutton = XtCreateManagedWidget("magstepButton",
-					  siagMenuButtonWidgetClass,
-					  menubox, NULL, ZERO);
-	label_set(magstepbutton, "Magstep");
+    magstepbutton = XtVaCreateManagedWidget("magstepButton",
+		mwMBButtonObjectClass, menubox,
+		XtNlabel, _("Magstep"),
+		XtNmenu_name, "magstep_menu",
+		(char *)0);
 
-    magstepmenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				     magstepbutton, NULL, ZERO);
+    magstepmenu = XtCreatePopupShell("magstep_menu", mwMenuWidgetClass,
+				     menubox, NULL, ZERO);
 
     magstepentry = (Widget *) XtMalloc(
 	    (app_res.maximum_magstep - app_res.minimum_magstep + 1) *
 	    sizeof(Widget));
-    XtSetArg(args[0], XtNleftMargin, 20);
     for (i = app_res.minimum_magstep; i <= app_res.maximum_magstep; i++) {
 	char buf[16];
 	sprintf(buf, "%d", i);
 	magstepentry[i-app_res.minimum_magstep] =
-		XtCreateManagedWidget(buf, smeBSBObjectClass,
-				      magstepmenu, args, 1);
+		XtVaCreateManagedWidget(buf,
+			mwLabelMEObjectClass, magstepmenu,
+			XtNlabel, buf,
+			XtNleft_icon, blank_bitmap,
+			(char *)0);
 	XtAddCallback(magstepentry[i-app_res.minimum_magstep], XtNcallback,
 		      set_magstep, (XtPointer)i);
     }
 
-    orientationbutton = XtCreateManagedWidget("orientationButton",
-					      siagMenuButtonWidgetClass,
-					      menubox, NULL, ZERO);
-	label_set(orientationbutton, "Orientation");
+    orientationbutton = XtVaCreateManagedWidget("orientationButton",
+				mwMBButtonObjectClass, menubox,
+				XtNmenu_name, "orientation_menu",
+				XtNlabel, _("Orientation"),
+				(char *)0);
 
-    orientationmenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				         orientationbutton, NULL, ZERO);
+    orientationmenu = XtVaCreatePopupShell("orientation_menu",
+				mwMenuWidgetClass, menubox,
+				(char *)0);
 
-    XtSetArg(args[0], XtNleftMargin, 20);
-    portraitbutton = XtCreateManagedWidget("portrait", smeBSBObjectClass,
-				           orientationmenu, args, ONE);
+    portraitbutton = XtVaCreateManagedWidget("portrait",
+				mwLabelMEObjectClass, orientationmenu,
+				XtNlabel, _("Portrait"),
+				XtNleft_icon, blank_bitmap,
+				(char *)0);
     XtAddCallback(portraitbutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationPortrait);
-	label_set(portraitbutton, "Portrait");
 
-    landscapebutton = XtCreateManagedWidget("landscape", smeBSBObjectClass,
-				            orientationmenu, args, ONE);
+    landscapebutton = XtVaCreateManagedWidget("landscape",
+				mwLabelMEObjectClass, orientationmenu,
+				XtNlabel, _("Landscape"),
+				XtNleft_icon, blank_bitmap,
+				(char *)0);
     XtAddCallback(landscapebutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationLandscape);
-	label_set(landscapebutton, "Landscape");
 
-    upsidedownbutton = XtCreateManagedWidget("upsidedown", smeBSBObjectClass,
-				             orientationmenu, args, ONE);
+    upsidedownbutton = XtVaCreateManagedWidget("upsidedown",
+				mwLabelMEObjectClass, orientationmenu,
+				XtNlabel, _("Upside-down"),
+				XtNleft_icon, blank_bitmap,
+				(char *)0);
     XtAddCallback(upsidedownbutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationUpsideDown);
-	label_set(upsidedownbutton, "Upside-down");
 
-    seascapebutton = XtCreateManagedWidget("seascape", smeBSBObjectClass,
-				             orientationmenu, args, ONE);
+    seascapebutton = XtVaCreateManagedWidget("seascape",
+				mwLabelMEObjectClass, orientationmenu,
+				XtNlabel, _("Seascape"),
+				XtNleft_icon, blank_bitmap,
+				(char *)0);
     XtAddCallback(seascapebutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationSeascape);
-	label_set(seascapebutton, "Seascape");
 
-    line = XtCreateManagedWidget("line", smeLineObjectClass,
+    line = XtCreateManagedWidget("line", mwLineMEObjectClass,
 				 orientationmenu, NULL, ZERO);
 
-    swapbutton = XtCreateManagedWidget("swap", smeBSBObjectClass,
-				       orientationmenu, args, ONE);
+    swapbutton = XtVaCreateManagedWidget("swap",
+				mwLabelMEObjectClass, orientationmenu,
+				XtNlabel, _("Swap Landscape"),
+				XtNleft_icon, blank_bitmap,
+				(char *)0);
     XtAddCallback(swapbutton, XtNcallback, swap_landscape, (XtPointer)0);
-	label_set(swapbutton, "Swap Landscape");
 
     if (app_res.swap_landscape) {
 	XtSetArg(args[0], XtNlabel, &s1);
@@ -739,10 +755,11 @@ int main(int argc, char **argv)
 	XtFree(s2);
     }
 
-    pagemediabutton = XtCreateManagedWidget("pagemediaButton",
-					    siagMenuButtonWidgetClass,
-					    menubox, NULL, ZERO);
-	label_set(pagemediabutton, "Media");
+    pagemediabutton = XtVaCreateManagedWidget("pagemediaButton",
+			mwMBButtonObjectClass, menubox,
+			XtNlabel, _("Media"),
+			XtNmenu_name, "pagemedia_menu",
+			(char *)0);
 
     default_pagemedia = 0;
     for (i = 0; papersizes[i].name; i++) {
@@ -752,20 +769,47 @@ int main(int argc, char **argv)
         }
     }
 
+    antialiasingbutton = XtVaCreateManagedWidget("antialiasingButton",
+			mwMBButtonObjectClass, menubox,
+			XtNlabel, _("Antialiasing"),
+			XtNmenu_name, "antialiasing_menu",
+			(char *)0);
+
     helpbutton = XtVaCreateManagedWidget("helpButton",
-		siagMenuButtonWidgetClass, menubox, (char *)0);
-	label_set(helpbutton, "Help");
-    helpmenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-	        helpbutton, NULL, ZERO);
-    helpbutton = XtCreateManagedWidget("help", smeBSBObjectClass,
-		helpmenu, NULL, ZERO);
-    label_set(helpbutton, "Contents");
+		mwMBButtonObjectClass, menubox,
+		XtNlabel, _("Help"),
+		XtNmenu_name, "help_menu",
+		XtNgravitation, XtCright,
+		(char *)0);
+    helpmenu = XtCreatePopupShell("help_menu", mwMenuWidgetClass,
+	        menubox, NULL, ZERO);
+    helpbutton = XtVaCreateManagedWidget("help",
+		mwLabelMEObjectClass, helpmenu,
+		XtNlabel, _("Contents"),
+		(char *)0);
     XtAddCallback(helpbutton, XtNcallback, help_cb, NULL);
-    copyrightbutton = XtCreateManagedWidget("copyright", smeBSBObjectClass,
-		helpmenu, NULL, ZERO);
-    label_set(copyrightbutton, "Copyright");
+    copyrightbutton = XtVaCreateManagedWidget("copyright",
+		mwLabelMEObjectClass, helpmenu,
+		XtNlabel, _("Copyright"),
+		(char *)0);
     XtAddCallback(copyrightbutton, XtNcallback, copyright_cb, NULL);
 
+    XtVaCreateManagedWidget("line",
+		mwLineMEObjectClass, helpmenu,
+		(char *)0);
+
+    aboutbutton = XtVaCreateManagedWidget("aboutgvu",
+		mwLabelMEObjectClass, helpmenu,
+		XtNlabel, _("About Gvu..."),
+		(char *)0);
+    XtAddCallback(aboutbutton, XtNcallback, aboutgvu_cb, NULL);
+
+    aboutbutton = XtVaCreateManagedWidget("aboutsiag",
+		mwLabelMEObjectClass, helpmenu,
+		XtNlabel, _("About Siag Office..."),
+		(char *)0);
+    XtAddCallback(aboutbutton, XtNcallback, aboutsiag_cb, NULL);
+
 #ifndef max
 #define max(a,b) ((a)>(b)?(a):(b))
 #endif
@@ -850,8 +894,8 @@ char *call;
 		"    [-[no]title] [-[no]date] [-[no]locator] [-[no]labels]\n"
 		"    [-resolution <dpi>] [-dpi <dpi>]\n"
 		"    [-xdpi <dpi>] [-ydpi <dpi>] [-magstep <n>]\n"
-		"    [-[no]safer] [-[no]quiet] [-arguments <arguments>]\n"
-		"    [-[no]center]\n"
+		"    [-[no]safer] [-[no]alpha] [-[no]quiet] [-[no]center]\n"
+		"    [-arguments <arguments>]\n"
 		"    [-portrait] [-landscape] [-upsidedown] [-seascape] [-[no]swap]\n"
 		"    [-letter] [-tabloid] [-ledger] [-legal] [-statement]\n"
 		"    [-executive] [-a3] [-a4] [-a5] [-b4] [-b5]\n"
