@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997, 1998  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,10 +22,7 @@
  * pw.h
  */
 
-#include "../common/richchar.h"
-#include "../common/fonts.h"
-
-#include "../common/traceme.h"
+#include <Mowitz/MwFormat.h>
 
 #define BUFFER_COLS 100000
 #define BUFFER_ROWS 100000
@@ -43,7 +40,7 @@ typedef struct {
 typedef struct s_style {
         char *name;             /* Default aso */
         unsigned int format;   /* bitwise OR of formats above */
-	sfmt fmt;		/* format description */
+	MwFmt fmt;		/* format description */
         int follower;           /* what style a new line gets */
 } style;
 
@@ -53,7 +50,7 @@ typedef struct rich_text {
         int sty;
         int adj;		/* left, right or center */
 	char bop;		/* beginning of paragraph */
-        rich_char *p;
+        MwRichchar *p;
 } rich_text;
 
 typedef struct plugin_t {
@@ -67,14 +64,14 @@ typedef struct sheet {
 	char *name;
 	position point_pos;	/* point */
 	position mark_pos;	/* mark */
-	position top;		/* left top of visible part of buffer */
 	position blku, blkl;	/* upper left & lower right block corners */
 
-	int alloc_lines;       /* number of allocated lines */
-	int used_lines;	/* number of used lines */
+	int alloc_lines;	/* number of allocated lines */
+	int used_lines;		/* number of used lines */
 	rich_text *text;	/* one pointer for each line */
 	plugin_t *plugin;	/* array of plugins */
 	int nplugin;		/* number of plugins */
+	char *tabs;		/* tab string */
 } sheet;
 
 typedef struct s_buffer {
@@ -91,7 +88,7 @@ typedef struct s_buffer {
 	int header_on_first;	/* default False */
 	int first_page_number;	/* default 1 */
 	int orientation;	/* default portrait */
-	int tab_distance;	/* default 36 */
+	int height_interest;	/* whether to calculate row height */
 	struct s_buffer *next;	/* next buffer in buffer ring */
 } buffer;
 
@@ -120,14 +117,6 @@ enum {PORTRAIT = 0, LANDSCAPE};
 #define block_upper(w) ((w)->buf->sht[(w)->bsht].blku)
 #define block_lower(w) ((w)->buf->sht[(w)->bsht].blkl)
 
-/* from richchar.c */
-extern size_t rc_strlen(rich_char *);
-extern rich_char *rc_strcpy(rich_char *, rich_char *);
-extern rich_char *rc_strcat(rich_char *, rich_char *);
-extern rich_char *rc_strdup(rich_char *);
-extern rich_char *rc_strins(rich_char *, rich_char *, size_t);
-extern rich_char *rc_makerich(unsigned char *, int);
-extern unsigned char *rc_makeplain(rich_char *);
 
 /* from window.c */
 extern window *w_list;
@@ -147,16 +136,14 @@ extern void hide_cur(window *);
 extern void get_char_coords(window *, int, int, int, int, int *, int *);
 extern void get_coords_cell(window *, int, int, int *, int *, int, int);
 
-/* from selection.c */
-extern void transfer_done_proc();	/* FIXME */
-
 /* from matrix.c */
 extern int nstyle;
 extern style *style_table;
 extern void do_bp_styles(void);
 extern char *style2name(int);
 extern int name2style(char *);
-extern int lookup_style(char *, char *, char *, int, int, int, int, char *);
+extern int lookup_style(char *, char *, char *,
+			int, int, int, int, int, char *);
 extern char **style_list(int *);
 extern int style_height(int);
 extern void save_styles(FILE *fp, int);
@@ -217,7 +204,6 @@ extern int buffer_remove_sheet(buffer *, int);
 extern void buffer_rename_sheet(buffer *, int, char *);
 extern buffer *new_buffer(char *, char *);
 extern buffer *free_buffer(buffer *);
-extern char *plugin_basedir(buffer *, char *);
 extern void plugin_unique_name(char *, char *);
 extern buffer *find_buffer_by_name(char *);
 extern buffer *find_sheet_by_name(char *, buffer *, int *);
