@@ -1,6 +1,6 @@
 /*
    Siag, Scheme In A Grid
-   Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 #include <math.h>
 #include "../siod/siod.h"
 #include "../common/common.h"
-#include "../common/cmalloc.h"
-#include "../common/fonts.h"
+#include <Mowitz/MwUtils.h>
+#include <Mowitz/MwFormat.h>
 #include "calc.h"
 
 /* ---
@@ -161,6 +161,7 @@ static int save_cell(FILE *fp, buffer *buf, int sh, int r, int c)
 		fwrite(b, 1, len+4, fp);
 		break;
 	case EXPRESSION:
+	case CONSTANT:
 		writeint(b, 0x0E);		/* type NUMBER */
 		len = 1+2+2+8;
 		writeint(b+2, len);		/* length 1+2+2+8 */
@@ -326,32 +327,32 @@ static int readfmt(unsigned char *p)
 #define WK1FMT_TIMEINTL1  11	
 #define WK1FMT_TIMEINTL2  12	
 
-	int format = FMT_DEFAULT;
+	int format = MW_FMT_DEFAULT;
 	char type, stype, decimals;
 
 	type = *p & WK1FMT_TYPE_MASK;
 	switch (type) {
 	case WK1FMT_FIXED:
-		format = FMT_FIXED;
+		format = MW_FMT_FIXED;
 		decimals = *p & WK1FMT_DECIMALS_MASK;
 		break;
 	case WK1FMT_SCIENTIFIC:
-		format = FMT_SCIENTIFIC;
+		format = MW_FMT_SCIENTIFIC;
 		decimals = *p & WK1FMT_DECIMALS_MASK;
 		break;
 	case WK1FMT_CURRENCY:
-		format = FMT_CURRENCY;
+		format = MW_FMT_CURRENCY;
 		decimals = *p & WK1FMT_DECIMALS_MASK;
 		break;
 	case WK1FMT_PERCENT:
-		format = FMT_PERCENT;
+		format = MW_FMT_PERCENT;
 		decimals = *p & WK1FMT_DECIMALS_MASK;
 		break;
 	case WK1FMT_COMMA:
-#ifndef FMT_COMMA
-#define FMT_COMMA FMT_DEFAULT
+#ifndef MW_FMT_COMMA
+#define MW_FMT_COMMA MW_FMT_DEFAULT
 #endif
-		format = FMT_COMMA;
+		format = MW_FMT_COMMA;
 		decimals = *p & WK1FMT_DECIMALS_MASK;
 		break;
 	case WK1FMT_SPECIAL:
@@ -364,11 +365,11 @@ static int readfmt(unsigned char *p)
 		case WK1FMT_DATEHHMM:
 		case WK1FMT_DATEINTL1:
 		case WK1FMT_DATEINTL2:
-			format = FMT_DATE;
+			format = MW_FMT_DATE;
 			break;
 		case WK1FMT_TIMEINTL1:
 		case WK1FMT_TIMEINTL2:
-			format = FMT_TIME;
+			format = MW_FMT_TIME;
 			break;
 		case WK1FMT_TEXT:
 			break;	/* Text */
@@ -399,23 +400,23 @@ static int makecoord(int orig, int coord)
 #define CASE0(n,s,m) \
 	case (n): \
 		sprintf(b, "(%s)", s); \
-		push(cstrdup(b)); \
+		push(MwStrdup(b)); \
 		i += (m); \
 		break;
 
 #define CASE1(n,s,m) \
 	case (n): \
 		p1 = pop(); \
-		sprintf(b, "(%s %s)", s, p1); cfree(p1); \
-		push(cstrdup(b)); \
+		sprintf(b, "(%s %s)", s, p1); MwFree(p1); \
+		push(MwStrdup(b)); \
 		i += (m); \
 		break;
 
 #define CASE2(n,s,m) \
 	case (n): \
 		p1 = pop(); q1 = pop(); \
-		sprintf(b, "(%s %s %s)", s, q1, p1); cfree(p1); cfree(q1); \
-		push(cstrdup(b)); \
+		sprintf(b, "(%s %s %s)", s, q1, p1); MwFree(p1); MwFree(q1); \
+		push(MwStrdup(b)); \
 		i += (m); \
 		break;
 
@@ -423,8 +424,8 @@ static int makecoord(int orig, int coord)
 	case (n): \
 		p1 = pop(); q1 = pop(); r1 = pop(); \
 		sprintf(b, "(%s %s %s %s)", s, r1, q1, p1); \
-		cfree(p1); cfree(q1); cfree(r1); \
-		push(cstrdup(b)); \
+		MwFree(p1); MwFree(q1); MwFree(r1); \
+		push(MwStrdup(b)); \
 		i += (m); \
 		break;
 
@@ -433,7 +434,7 @@ static int makecoord(int orig, int coord)
                 sprintf(b, "(%s", s); \
                 addargs(b, p[i+1]); \
                 strcat(b, ")"); \
-                push(cstrdup(b)); \
+                push(MwStrdup(b)); \
                 i += (m); \
                 break;
 
@@ -459,7 +460,7 @@ static void formula(int len, unsigned char *p, int r, int c)
 		switch (p[i]) {
 		case 0x00:
 			sprintf(b, "%f", readfloat(p+i+1));
-			push(cstrdup(b));
+			push(MwStrdup(b));
 			i += 9;
 			break;
 		case 0x01:
@@ -472,7 +473,7 @@ static void formula(int len, unsigned char *p, int r, int c)
        	                         	a1coord(1+makecoord(c, readint(p+i+1))),
        	                         	1+makecoord(r, readint(p+i+3)));
 			}
-			push(cstrdup(b));
+			push(MwStrdup(b));
 			i += 5;
 			break;
 		case 0x02:
@@ -490,7 +491,7 @@ static void formula(int len, unsigned char *p, int r, int c)
                                 	a1coord(1+makecoord(c, readint(p+i+5))),
                                 	1+makecoord(r, readint(p+i+7)));
 			}
-			push(cstrdup(b));
+			push(MwStrdup(b));
 			i += 9;
 			break;
 		case 0x03:
@@ -500,7 +501,7 @@ static void formula(int len, unsigned char *p, int r, int c)
 			break;
 		case 0x05:
 			sprintf(b, "%d", readsint(p+i+1));
-			push(cstrdup(b));
+			push(MwStrdup(b));
 			i += 3;
 			break;
 		case 0x06:
@@ -513,7 +514,7 @@ static void formula(int len, unsigned char *p, int r, int c)
 			}
 			*p1++ = '"';
 			*p1 = '\0';
-			push(cstrdup(b));
+			push(MwStrdup(b));
 			i++;
 			break;
 		CASE1(0x08, "-", 1);
@@ -632,7 +633,7 @@ static void formula(int len, unsigned char *p, int r, int c)
 
 static void wk1(FILE *fp, buffer *buf)
 {
-        int i, j, sf = fmt_new2old(0), f, rf;
+        int i, j, sf = MwFmtNewToOld(0), f, rf;
 	char b[2000];
 	char *p1;
 	cval value;
@@ -649,21 +650,21 @@ static void wk1(FILE *fp, buffer *buf)
 		}
 		type = readint(head);
 		len = readint(head+2);
-		p = cmalloc(len);
+		p = MwMalloc(len);
 		if (!p) {
 			fprintf(stderr, "Couldn't allocate %d bytes\n", len);
 			return;
 		}
 		if (fread(p, 1, len, fp) != len) {
 			fprintf(stderr, "Couldn't read %d bytes\n", len);
-			cfree(p);
+			MwFree(p);
 			return;
 		}
 		switch (type) {
 		case 0x00:
 			break;
 		case 0x01:
-			cfree(p);
+			MwFree(p);
 			return;
 		case 0x08:
 			break;
@@ -674,14 +675,14 @@ static void wk1(FILE *fp, buffer *buf)
 			j = 1+readint(p+1);
 			rf = readfmt(p); 
 			f = sf | rf;
-			if (rf == FMT_DATE) {
+			if (rf == MW_FMT_DATE) {
 				value.number 
 					= from_wk1date(value.number,FALSE);
 				sprintf(b, "%d", (int)value.number);
 			}
 			ins_data(buf, siod_interpreter, b,
 				value, EXPRESSION, s, i, j);
-			ins_format(buf,	s, i, j, fmt_old2new(f));
+			ins_format(buf,	s, i, j, MwFmtOldToNew(f));
 			break;
 		case 0x0E:
 			value.number = readfloat(p+5);
@@ -690,14 +691,14 @@ static void wk1(FILE *fp, buffer *buf)
 			j = 1+readint(p+1);
 			rf = readfmt(p); 
 			f = sf | rf;
-			if (rf == FMT_DATE || rf == FMT_TIME) {
+			if (rf == MW_FMT_DATE || rf == MW_FMT_TIME) {
 				value.number = from_wk1date(value.number, 
-							    rf == FMT_TIME);
+							    rf == MW_FMT_TIME);
 				sprintf(b, "%d", (int) value.number);
 			}
 			ins_data(buf, siod_interpreter, b,
 				value, EXPRESSION, s, i, j);
-			ins_format(buf,	s, i, j, fmt_old2new(f));
+			ins_format(buf,	s, i, j, MwFmtOldToNew(f));
 			break;
 		case 0x0F:
 			switch (p[5]) {
@@ -716,7 +717,7 @@ static void wk1(FILE *fp, buffer *buf)
 			f = sf | readfmt(p); 
 			ins_data(buf, siod_interpreter, (char *)p+6,
 				value, LABEL, s, i, j);
-			ins_format(buf,	s, i, j, fmt_old2new(f));
+			ins_format(buf,	s, i, j, MwFmtOldToNew(f));
 			break;
 		case 0x10:
 		/* 5-12 = value */
@@ -729,13 +730,13 @@ static void wk1(FILE *fp, buffer *buf)
 			value.number = readfloat(p+5);
 			ins_data(buf, siod_interpreter, p1,
 				value, EXPRESSION, s, i+1, j+1);
-			cfree(p1);
-			ins_format(buf,	s, i+1, j+1, fmt_old2new(f));
+			MwFree(p1);
+			ins_format(buf,	s, i+1, j+1, MwFmtOldToNew(f));
 			break;
 		default:
 			break;
 		}
-		cfree(p);
+		MwFree(p);
 	}
 }
 
@@ -764,7 +765,7 @@ static int myformat(char *fn)
 
         ext = strrchr(fn, '.');
         if (!ext) return 0;     /* no extension */
-        if (cstrcasecmp(ext, ".wk1") && cstrcasecmp(ext, ".wks"))
+        if (MwStrcasecmp(ext, ".wk1") && MwStrcasecmp(ext, ".wks"))
                 return 0;       /* wrong extension */
         if ((fp = fopen(fn, "rb")) == NULL) return 0;    /* can't open */
         if (fread(b, 1, 4, fp) != 4) {		/* can't read */
