@@ -42,7 +42,7 @@
 "XedPlus*dirty.gridx:			3",
 "XedPlus*dirty.gridy:			1",
 "XedPlus*dirty.shadowWidth:		1",
-"XedPlus*dirty.font:			-*-helvetica-bold-r-*-12-*",
+"XedPlus*dirty.font:			-*-helvetica-bold-r-*-*-12-*-*-*-*-*-iso8859-*",
 "XedPlus*buttons*orientation:		horizontal",
 "XedPlus*buttons*showGrip:		False",
 "XedPlus*input:			        TRUE",
