@@ -51,7 +51,7 @@
 "Pw*viewport.yLayout:			25 100% 17",
 "Pw*ruler.gridWidth:			4",
 "Pw*ruler.borderWidth:			0",
-"Pw*ruler.font:				-*-helvetica-medium-r-*-10-*",
+"Pw*ruler.font:				-*-helvetica-medium-r-*-*-10-*-*-*-*-*-iso8859-*",
 "Pw*grid.gridy:				1",
 "Pw*grid.gridWidth:			4",
 "Pw*grid.background:			white",
@@ -90,75 +90,43 @@
 	:<Btn1Motion>:			grid-button(adjust)		\\n\
 	:<Btn2Down>:			grid-button(paste)		\\n\
 	Shift<Btn3Down>:		grid-button(select)		\\n\
-	:<Btn3Down>:			popup-shortcuts() \\n\
-	:<Key>Home:			execute(beginning-of-line)	\\n\
-	Ctrl<Key>a:			execute(beginning-of-line)	\\n\
-	:<Key>End:			execute(end-of-line)		\\n\
-	Ctrl<Key>e:			execute(end-of-line)		\\n\
-	Ctrl<Key>space:			execute(set-mark-command)	\\n\
-	<Key>space:			self-insert-char()		\\n\
+	:<Btn3Down>:			popup-shortcuts()		\\n\
 	:<Key>Left:			execute(backward-char)		\\n\
-	Ctrl<Key>b:			execute(backward-char)		\\n\
-	:<Key>Delete:			execute(delete-char)		\\n\
-	Ctrl<Key>d:			execute(delete-char)		\\n\
-	:<Key>BackSpace:		execute(delete-char-backward)	\\n\
 	:<Key>Right:			execute(forward-char)		\\n\
-	Ctrl<Key>f:			execute(forward-char)		\\n\
 	:<Key>Down:			execute(next-line)		\\n\
-	Ctrl<Key>n:			execute(next-line)		\\n\
-	Ctrl<Key>o:			execute(split-line)		\\n\
+	:<Key>Up:			execute(previous-line)		\\n\
+	:<Key>Home:			execute(beginning-of-line)	\\n\
+	:<Key>End:			execute(end-of-line)		\\n\
+	:Ctrl<Key>Home:			execute(beginning-of-buffer)	\\n\
+	:Ctrl<Key>End:			execute(end-of-buffer)		\\n\
+	:<Key>Page_Up:			execute(scroll-up)		\\n\
+	:<Key>Page_Down:		execute(scroll-down)		\\n\
+	:<Key>Delete:			execute(delete-char)		\\n\
+	:<Key>BackSpace:		execute(delete-char-backward)	\\n\
 	:<Key>Return:			execute(newline)		\\n\
+	Meta<Key>x:			execute(execute-extended-command)\\n\
+	:<Key>F1:			execute(help-contents)		\\n\
+	:<Key>F4:			execute(more complicated test)	\\n\
+	Ctrl<Key>b:			execute(toggle-format BOLD)	\\n\
+	Ctrl<Key>c:			execute(copy-block-to-string)	\\n\
+	Ctrl<Key>e:			execute(change-hadjust HADJ_CENTER)\\n\
+	Ctrl<Key>f:			execute(search-forward)		\\n\
+	Ctrl<Key>h:			execute(delete-char-backward)	\\n\
+	Ctrl<Key>i:			execute(toggle-format ITALIC)	\\n\
+	Ctrl<Key>j:			execute(change-hadjust HADJ_FULL)\\n\
 	Ctrl<Key>k:			execute(kill-line)		\\n\
 	Ctrl<Key>l:			execute(recenter)		\\n\
-	Ctrl<Key>x,Ctrl<Key>f:		execute(load-buffer)		\\n\
-	Ctrl<Key>x,Ctrl<Key>d:		execute(debug-format)		\\n\
-	:<Key>Up:			execute(previous-line)		\\n\
-	Ctrl<Key>p:			execute(previous-line)		\\n\
-	Ctrl<Key>x,Ctrl<Key>c:		execute(quit-program)		\\n\
-	Ctrl<Key>x,Ctrl<Key>s:		execute(save-buffer)		\\n\
-	Ctrl<Key>x,Ctrl<Key>w:		execute(save-buffer-as)		\\n\
-	Ctrl<Key>x,Ctrl<Key>x:		execute(exchange-point-and-mark)\\n\
-	Ctrl<Key>x,Ctrl<Key>space: 	execute(set-block)		\\n\
-	Meta<Key>x:			execute(execute-extended-command)\\n\
-	:Meta<Key>less:			execute(beginning-of-buffer)	\\n\
-	:Meta<Key>greater:		execute(end-of-buffer)		\\n\
-	:<Key>Page_Up:			execute(scroll-up)		\\n\
-	Meta<Key>v:			execute(scroll-up)		\\n\
-	:<Key>Page_Down:		execute(scroll-down)		\\n\
-	Ctrl<Key>v:			execute(scroll-down)		\\n\
-	Ctrl<Key>w:			execute(delete-block)		\\n\
-	Ctrl<Key>x,<Key>question: 	execute(what-cursor-position)	\\n\
-	<Key>question:			self-insert-char()		\\n\
-	Ctrl<Key>x,<Key>k:		execute(kill-buffer)		\\n\
-	<Key>k:				self-insert-char()		\\n\
-	Ctrl<Key>x,<Key>b:		execute(switch-to-buffer)	\\n\
-	<Key>b:				self-insert-char()		\\n\
-	Ctrl<Key>x,<Key>2:		execute(split-window-vertically)\\n\
-	<Key>2:				self-insert-char()		\\n\
-	Ctrl<Key>x,<Key>1:		execute(delete-other-windows)	\\n\
-	<Key>1:				self-insert-char()		\\n\
-	Ctrl<Key>x,<Key>0:		execute(delete-window)		\\n\
-	<Key>0:				self-insert-char()		\\n\
-	Ctrl<Key>x,<Key>o:		execute(other-window)		\\n\
-	<Key>o:				self-insert-char()		\\n\
-	:<Key>F1:			execute(help-contents)		\\n\
-	Ctrl<Key>h,<Key>c:		execute(help-contents)		\\n\
-	<Key>c:				self-insert-char()		\\n\
-	:<Key>F4:			execute(more complicated test)	\\n\
-	:<Key>a:			self-insert-char()		\\n\
-	:<Key>A:			self-insert-char()		\\n\
-	Ctrl<Key>c,Ctrl<Key>c:		execute(copy-block-to-string)	\\n\
-	Ctrl<Key>c,Ctrl<Key>f:		execute(search-forward)		\\n\
-	Ctrl<Key>c,Ctrl<Key>g:		execute(keyboard-quit)		\\n\
-	Ctrl<Key>c,Ctrl<Key>n:		execute(new-buffer)		\\n\
-	Ctrl<Key>c,Ctrl<Key>o:		execute(load-buffer)		\\n\
-	Ctrl<Key>c,Ctrl<Key>p:		execute(print)			\\n\
-	Ctrl<Key>c,Ctrl<Key>q:		execute(quit-program)		\\n\
-	Ctrl<Key>c,Ctrl<Key>s:		execute(save-buffer-as)		\\n\
-	Ctrl<Key>c,Ctrl<Key>v:		execute(paste-block-from-string)\\n\
-	Ctrl<Key>c,Ctrl<Key>w:		execute(kill-buffer)		\\n\
-	Ctrl<Key>c,Ctrl<Key>x:		execute(cut-block-to-string)	\\n\
-	Ctrl<Key>c,Ctrl<Key>z:		execute(undo-restore)		\\n\
+	Ctrl<Key>n:			execute(new-buffer)		\\n\
+	Ctrl<Key>o:			execute(load-buffer)		\\n\
+	Ctrl<Key>p:			execute(print)			\\n\
+	Ctrl<Key>q:			execute(quit-program)		\\n\
+	Ctrl<Key>r:			execute(change-hadjust HADJ_RIGHT)\\n\
+	Ctrl<Key>s:			execute(save-buffer-as)		\\n\
+	Ctrl<Key>u:			execute(toggle-format ULINE)	\\n\
+	Ctrl<Key>v:			execute(paste-block-from-string)\\n\
+	Ctrl<Key>w:			execute(kill-buffer)		\\n\
+	Ctrl<Key>x:			execute(cut-block-to-string)	\\n\
+	Ctrl<Key>z:			execute(undo-restore)		\\n\
 	<Key>:				self-insert-char()",
 "Pw*plugin-parent.translations:\
 	<Btn1Down>:			plugin-resize()	\\n\
