@@ -79,6 +79,42 @@
 	:<Key>F3:		popup-shortcuts()			\\n\
 	:<Key>F1:		execute(help-contents)			\\n\
 	:<Key>F9:		execute(recalc-matrix)			\\n\
+	:Ctrl<Key>Left:		execute(scroll_right)			\\n\
+	:<Key>Left:		execute(backward_cell)			\\n\
+	:Ctrl<Key>Right:	execute(scroll_left)			\\n\
+	:<Key>Right:		execute(forward_cell)			\\n\
+	:Ctrl<Key>Up:		execute(top_of_buffer)			\\n\
+	:<Key>Up:		execute(previous_line)			\\n\
+	:Ctrl<Key>Down:		execute(bottom_of_buffer)		\\n\
+	:<Key>Down:		execute(next_line)			\\n\
+	:Ctrl<Key>Home:		execute(beginning_of_buffer)		\\n\
+	:<Key>Home:		execute(beginning_of_line)		\\n\
+	:Ctrl<Key>End:		execute(end_of_buffer)			\\n\
+	:<Key>End:		execute(end_of_line)			\\n\
+	:Ctrl<Key>Page_Up:	execute(top_of_buffer)			\\n\
+	:<Key>Page_Up:		execute(scroll_up)			\\n\
+	:Ctrl<Key>Page_Down:	execute(bottom_of_buffer)		\\n\
+	:<Key>Page_Down:	execute(scroll_down)			\\n\
+	:<Key>Delete:		execute(delete_cell)			\\n\
+	:Ctrl<Key>a:		execute(select_all)			\\n\
+	:Ctrl<Key>b:		execute(toggle_format BOLD)		\\n\
+	:Ctrl<Key>c:		execute(copy_block_to_string)		\\n\
+	:Ctrl<Key>e:		execute(new_format HADJ HADJ_CENTER)	\\n\
+	:Ctrl<Key>f:		execute(search_forward)			\\n\
+	:Ctrl<Key>g:		execute(go_to)				\\n\
+	:Ctrl<Key>i:		execute(toggle_format ITALIC)		\\n\
+	:Ctrl<Key>l:		execute(recenter)			\\n\
+	:Ctrl<Key>n:		execute(new_buffer)			\\n\
+	:Ctrl<Key>o:		execute(load_buffer)			\\n\
+	:Ctrl<Key>p:		execute(print)				\\n\
+	:Ctrl<Key>q:		execute(quit_program)			\\n\
+	:Ctrl<Key>r:		execute(new_format HADJ HADJ_RIGHT)	\\n\
+	:Ctrl<Key>s:		execute(save_buffer_as)			\\n\
+	:Ctrl<Key>u:		execute(toggle_format ULINE)		\\n\
+	:Ctrl<Key>v:		execute(paste_block_from_string)	\\n\
+	:Ctrl<Key>w:		execute(kill_buffer 1)			\\n\
+	:Ctrl<Key>x:		execute(cut_block_to_string)		\\n\
+	:Ctrl<Key>z:		execute(undo_restore)			\\n\
 	<Key>:			key-event()",
 "Siag*tabl.gridy:		2",
 "Siag*tabl.label:		<<",
